@@ -29,21 +29,30 @@ dc1394_capture_setup (dc1394camera_t *camera, uint32_t num_dma_buffers,
         uint32_t flags)
 {
     dc1394camera_priv_t * cpriv = DC1394_CAMERA_PRIV (camera);
-    return platform_capture_setup (cpriv->pcam, num_dma_buffers, flags);
+    const platform_dispatch_t * d = cpriv->platform->dispatch;
+    if (!d->capture_setup)
+        return DC1394_FUNCTION_NOT_SUPPORTED;
+    return d->capture_setup (cpriv->pcam, num_dma_buffers, flags);
 }
 
 dc1394error_t
 dc1394_capture_stop (dc1394camera_t *camera)
 {
     dc1394camera_priv_t * cpriv = DC1394_CAMERA_PRIV (camera);
-    return platform_capture_stop (cpriv->pcam);
+    const platform_dispatch_t * d = cpriv->platform->dispatch;
+    if (!d->capture_stop)
+        return DC1394_FUNCTION_NOT_SUPPORTED;
+    return d->capture_stop (cpriv->pcam);
 }
 
 int
 dc1394_capture_get_fileno (dc1394camera_t * camera)
 {
     dc1394camera_priv_t * cpriv = DC1394_CAMERA_PRIV (camera);
-    return platform_capture_get_fileno (cpriv->pcam);
+    const platform_dispatch_t * d = cpriv->platform->dispatch;
+    if (!d->capture_get_fileno)
+        return DC1394_FUNCTION_NOT_SUPPORTED;
+    return d->capture_get_fileno (cpriv->pcam);
 }
 
 dc1394error_t
@@ -51,14 +60,20 @@ dc1394_capture_dequeue (dc1394camera_t * camera, dc1394capture_policy_t policy,
         dc1394video_frame_t **frame)
 {
     dc1394camera_priv_t * cpriv = DC1394_CAMERA_PRIV (camera);
-    return platform_capture_dequeue (cpriv->pcam, policy, frame);
+    const platform_dispatch_t * d = cpriv->platform->dispatch;
+    if (!d->capture_dequeue)
+        return DC1394_FUNCTION_NOT_SUPPORTED;
+    return d->capture_dequeue (cpriv->pcam, policy, frame);
 }
 
 dc1394error_t
 dc1394_capture_enqueue (dc1394camera_t * camera, dc1394video_frame_t * frame)
 {
     dc1394camera_priv_t * cpriv = DC1394_CAMERA_PRIV (camera);
-    return platform_capture_enqueue (cpriv->pcam, frame);
+    const platform_dispatch_t * d = cpriv->platform->dispatch;
+    if (!d->capture_enqueue)
+        return DC1394_FUNCTION_NOT_SUPPORTED;
+    return d->capture_enqueue (cpriv->pcam, frame);
 }
 
 dc1394bool_t
@@ -68,5 +83,8 @@ dc1394_capture_is_frame_corrupt (dc1394camera_t * camera,
     dc1394camera_priv_t * cpriv = DC1394_CAMERA_PRIV (camera);
     if (!frame)
         return DC1394_TRUE;
-    return platform_capture_is_frame_corrupt (cpriv->pcam, frame);
+    const platform_dispatch_t * d = cpriv->platform->dispatch;
+    if (!d->capture_is_frame_corrupt)
+        return DC1394_FALSE;
+    return d->capture_is_frame_corrupt (cpriv->pcam, frame);
 }
