@@ -1955,7 +1955,7 @@ dc1394_new (void)
     windows_init (d);
 #endif
 #ifdef HAVE_LIBUSB
-    usb_init (d);
+    dc1394_usb_init (d);
 #endif
 
     int i;
@@ -2183,13 +2183,11 @@ dc1394_camera_free(dc1394camera_t *camera)
 {
     dc1394camera_priv_t * cpriv = DC1394_CAMERA_PRIV (camera);
 
-    if (cpriv->iso_persist)
-        dc1394_iso_release_all (camera);
+    if (cpriv->iso_persist!=1)
+        dc1394_iso_release_all(camera);
 
     cpriv->platform->dispatch->camera_free (cpriv->pcam);
     free (camera->vendor);
     free (camera->model);
     free (camera);
 }
-
-
