@@ -190,7 +190,7 @@ dc1394_juju_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
     craw->current = -1;
     craw->buffer_size = proto.total_bytes * num_dma_buffers;
     craw->buffer =
-        mmap(NULL, craw->buffer_size, PROT_READ, MAP_SHARED, craw->iso_fd, 0);
+        mmap(NULL, craw->buffer_size, PROT_READ | PROT_WRITE , MAP_SHARED, craw->iso_fd, 0);
     err = DC1394_IOCTL_FAILURE;
     if (craw->buffer == MAP_FAILED)
         goto error_fd;
@@ -261,6 +261,7 @@ dc1394_juju_capture_stop(platform_camera_t *craw)
 {
     dc1394camera_t * camera = craw->camera;
     struct fw_cdev_stop_iso stop;
+    int i;
 
     if (craw->capture_is_set == 0)
         return DC1394_CAPTURE_IS_NOT_SET;
@@ -271,6 +272,8 @@ dc1394_juju_capture_stop(platform_camera_t *craw)
 
     munmap(craw->buffer, craw->buffer_size);
     close(craw->iso_fd);
+    for (i = 0; i<craw->num_frames; i++)
+        release_frame(craw, i);
     free (craw->frames);
     craw->frames = NULL;
     craw->capture_is_set = 0;
