@@ -2,8 +2,9 @@
  * 1394-Based Digital Camera Control Library
  *
  * Juju backend for dc1394
- * 
+ *
  * Written by Kristian Hoegsberg <krh@bitplanet.net>
+ * Maintained by David Moore <dcm@acm.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,7 +24,7 @@
 #ifndef __DC1394_JUJU_H__
 #define __DC1394_JUJU_H__
 
-#include <linux/firewire-cdev.h>
+#include "firewire-cdev.h"
 #include "config.h"
 #include "internal.h"
 #include "register.h"
@@ -33,11 +34,24 @@ struct _platform_t {
     int dummy;
 };
 
+typedef struct _juju_iso_info {
+    int got_alloc;
+    int got_dealloc;
+    int handle;
+    int channel;
+    int bandwidth;
+    struct _juju_iso_info *next;
+} juju_iso_info;
+
 struct _platform_camera_t {
     int fd;
     char filename[32];
     int generation;
     uint32_t node_id;
+    int max_response_quads;
+    juju_iso_info *iso_resources;
+    uint8_t header_size;
+    uint8_t broadcast_enabled;
 
     dc1394camera_t * camera;
 
@@ -49,11 +63,11 @@ struct _platform_camera_t {
     uint32_t flags;
     unsigned int num_frames;
     int current;
-    int ready_frames;
 
     unsigned int iso_channel;
     int capture_is_set;
     int iso_auto_started;
+    juju_iso_info *capture_iso_resource;
 };
 
 
@@ -64,6 +78,28 @@ struct juju_frame {
 };
 
 dc1394error_t
-_juju_iterate(dc1394camera_t *camera);
+dc1394_juju_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
+        uint32_t flags);
+
+dc1394error_t
+dc1394_juju_capture_stop(platform_camera_t *craw);
+
+dc1394error_t
+dc1394_juju_capture_dequeue (platform_camera_t * craw,
+        dc1394capture_policy_t policy, dc1394video_frame_t **frame_return);
+
+dc1394error_t
+dc1394_juju_capture_enqueue (platform_camera_t * craw,
+        dc1394video_frame_t * frame);
+
+int
+dc1394_juju_capture_get_fileno (platform_camera_t * craw);
+
+dc1394error_t
+juju_iso_allocate (platform_camera_t *cam, uint64_t allowed_channels,
+        int bandwidth_units, juju_iso_info **out);
+
+dc1394error_t
+juju_iso_deallocate (platform_camera_t *cam, juju_iso_info * res);
 
 #endif
