@@ -26,28 +26,13 @@
 #include <inttypes.h>
 #include <pthread.h>
 #include <unistd.h>
-#include <sys/time.h>
-#ifdef HAVE_MACOSX
-#include <CoreFoundation/CoreFoundation.h>
-#endif
-#include "usb/usb.h"
 
-// LIBUSB_CALL only defined for latest libusb versions.
-#ifndef LIBUSB_CALL
-#define LIBUSB_CALL
-#endif
+#include "usb/usb.h"
 
 /* Callback whenever a bulk transfer finishes. */
 static void
-LIBUSB_CALL callback (struct libusb_transfer * transfer)
+callback (struct libusb_transfer * transfer)
 {
-	// Get a software timestamp as soon as possible in this callback. Note that this timestamp
-	// is not as accurate as the bus timestamp we get with the IEEE1394 interface. For more
-	// accurate timings, consider using either a hardware external trigger or the camera
-	// timestamps that can be inserted within the video frame (see Point Grey documentation)
-	struct timeval filltime;
-	gettimeofday(&filltime,NULL);
-
     struct usb_frame * f = transfer->user_data;
     platform_camera_t * craw = f->pcam;
 
@@ -70,7 +55,6 @@ LIBUSB_CALL callback (struct libusb_transfer * transfer)
 
     pthread_mutex_lock (&craw->mutex);
     f->status = status;
-	f->frame.timestamp = filltime.tv_sec*1000000 + filltime.tv_usec;
     craw->frames_ready++;
     pthread_mutex_unlock (&craw->mutex);
 
@@ -80,19 +64,6 @@ LIBUSB_CALL callback (struct libusb_transfer * transfer)
     }
 }
 
-#ifdef HAVE_MACOSX
-static void
-socket_callback_usb (CFSocketRef s, CFSocketCallBackType type,
-                 CFDataRef address, const void * data, void * info)
-{
-    platform_camera_t * craw = info;
-    dc1394capture_t * capture = &(craw->capture);
-    if (capture->callback) {
-        capture->callback (craw->camera, capture->callback_user_data);
-    }
-}
-#endif
-
 static void *
 capture_thread (void * arg)
 {
@@ -116,51 +87,13 @@ capture_thread (void * arg)
     return NULL;
 }
 
-static int
-find_interface (libusb_device * usb_dev, uint8_t endpoint_address)
-{
-    struct libusb_device_descriptor usb_desc;
-    struct libusb_config_descriptor * config_desc;
-    int ret;
-    int i, a, e;
-    uint8_t ea;
-
-    ret = libusb_get_device_descriptor(usb_dev, &usb_desc);
-
-    if (ret < 0) {
-        dc1394_log_error ("usb: Failed to get device descriptor");
-        return DC1394_FAILURE;
-    }
-
-    if (usb_desc.bNumConfigurations) {
-        ret = libusb_get_active_config_descriptor (usb_dev, &config_desc);
-        if (ret) {
-            dc1394_log_error ("usb: Failed to get config descriptor");
-            return DC1394_FAILURE;
-        }
-
-        for (i = 0; i < config_desc->bNumInterfaces; i++) {
-            for (a = 0; a < config_desc->interface[i].num_altsetting; a++) {
-                for (e = 0; e < config_desc->interface[i].altsetting[a].bNumEndpoints; e++) {
-                    ea = config_desc->interface[i].altsetting[a].endpoint[e].bEndpointAddress;
-                    // Return the interface number for the first suitable interface
-                    if (ea == endpoint_address)
-                        return i;
-                }
-            }
-        }
-    }
-
-    return DC1394_FAILURE;
-}
-
 static dc1394error_t
-init_frame(platform_camera_t *craw, int index, dc1394video_frame_t *proto, size_t padded_frame_size)
+init_frame(platform_camera_t *craw, int index, dc1394video_frame_t *proto)
 {
     struct usb_frame *f = craw->frames + index;
 
     memcpy (&f->frame, proto, sizeof f->frame);
-    f->frame.image = craw->buffer + index * padded_frame_size;
+    f->frame.image = craw->buffer + index * proto->total_bytes;
     f->frame.id = index;
     f->transfer = libusb_alloc_transfer (0);
     f->pcam = craw;
@@ -176,15 +109,11 @@ dc1394_usb_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
     int i;
     dc1394camera_t * camera = craw->camera;
 
-#ifdef HAVE_MACOSX
-    dc1394capture_t * capture = &(craw->capture);
-    CFSocketContext socket_context = { 0, craw, NULL, NULL, NULL };
-#endif
-
     // if capture is already set, abort
     if (craw->capture_is_set > 0)
         return DC1394_CAPTURE_IS_RUNNING;
 
+    craw->capture_is_set = 1;
 
     if (flags & DC1394_CAPTURE_FLAGS_DEFAULT)
         flags = DC1394_CAPTURE_FLAGS_CHANNEL_ALLOC |
@@ -197,40 +126,19 @@ dc1394_usb_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
         dc1394_usb_capture_stop (craw);
         return DC1394_FAILURE;
     }
-    size_t padded_frame_size = proto.total_bytes;
-    if (libusb_get_device_speed(libusb_get_device(craw->handle)) == LIBUSB_SPEED_SUPER) {
-        proto.total_bytes = proto.image_bytes;
-        padded_frame_size = (proto.total_bytes + 1023) & ~1023;
-    }
+
     if (pipe (craw->notify_pipe) < 0) {
         dc1394_usb_capture_stop (craw);
         return DC1394_FAILURE;
     }
 
-#ifdef HAVE_MACOSX
-    capture->socket = CFSocketCreateWithNative (NULL, craw->notify_pipe[0],
-                                                kCFSocketReadCallBack, socket_callback_usb, &socket_context);
-    /* Set flags so that the underlying fd is not closed with the socket */
-    CFSocketSetSocketFlags (capture->socket,
-                            CFSocketGetSocketFlags (capture->socket) & ~kCFSocketCloseOnInvalidate);
-    capture->socket_source = CFSocketCreateRunLoopSource (NULL,
-                                                          capture->socket, 0);
-    if (!capture->run_loop)
-        dc1394_usb_capture_schedule_with_runloop (craw,
-                                              CFRunLoopGetCurrent (), kCFRunLoopCommonModes);
-    CFRunLoopAddSource (capture->run_loop, capture->socket_source,
-                        capture->run_loop_mode);
-#endif
-
-    craw->capture_is_set = 1;
-
     dc1394_log_debug ("usb: Frame size is %"PRId64, proto.total_bytes);
 
     craw->num_frames = num_dma_buffers;
     craw->current = -1;
     craw->frames_ready = 0;
     craw->queue_broken = 0;
-    craw->buffer_size = padded_frame_size * num_dma_buffers;
+    craw->buffer_size = proto.total_bytes * num_dma_buffers;
     craw->buffer = malloc (craw->buffer_size);
     if (craw->buffer == NULL) {
         dc1394_usb_capture_stop (craw);
@@ -244,7 +152,7 @@ dc1394_usb_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
     }
 
     for (i = 0; i < num_dma_buffers; i++)
-        init_frame(craw, i, &proto, padded_frame_size);
+        init_frame(craw, i, &proto);
 
     if (libusb_init(&craw->thread_context) != 0) {
         dc1394_log_error ("usb: Failed to create thread USB context");
@@ -277,14 +185,7 @@ dc1394_usb_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
     }
     libusb_free_device_list (list, 1);
 
-	// Point Grey uses endpoint 0x81, but other manufacturers or models may use another endpoint
-    int usb_interface = find_interface (libusb_get_device(craw->thread_handle), 0x81);
-    if (usb_interface == DC1394_FAILURE) {
-        dc1394_log_error ("usb: capture thread failed to find suitable interface on device");
-        dc1394_usb_capture_stop (craw);
-        return DC1394_FAILURE;
-    }
-    if (libusb_claim_interface (craw->thread_handle, usb_interface) < 0) {
+    if (libusb_claim_interface (craw->thread_handle, 0) < 0) {
         dc1394_log_error ("usb: capture thread failed to claim interface");
         dc1394_usb_capture_stop (craw);
         return DC1394_FAILURE;
@@ -330,9 +231,6 @@ dc1394_usb_capture_stop(platform_camera_t *craw)
 {
     dc1394camera_t * camera = craw->camera;
     int i;
-#ifdef HAVE_MACOSX
-    dc1394capture_t * capture = &(craw->capture);
-#endif
 
     if (craw->capture_is_set == 0)
         return DC1394_CAPTURE_IS_NOT_SET;
@@ -376,21 +274,6 @@ dc1394_usb_capture_stop(platform_camera_t *craw)
         craw->thread_context = NULL;
     }
 
-#ifdef HAVE_MACOSX
-    if (capture->socket_source) {
-        CFRunLoopRemoveSource (capture->run_loop, capture->socket_source,
-                               capture->run_loop_mode);
-        CFRelease (capture->socket_source);
-    }
-    capture->socket_source = NULL;
-
-    if (capture->socket) {
-        CFSocketInvalidate (capture->socket);
-        CFRelease (capture->socket);
-    }
-    capture->socket = NULL;
-#endif
-
     if (craw->frames) {
         for (i = 0; i < craw->num_frames; i++) {
             libusb_free_transfer (craw->frames[i].transfer);
@@ -423,14 +306,9 @@ dc1394_usb_capture_dequeue (platform_camera_t * craw,
     int next = NEXT_BUFFER (craw, craw->current);
     struct usb_frame * f = craw->frames + next;
 
-    if (policy < DC1394_CAPTURE_POLICY_MIN || policy > DC1394_CAPTURE_POLICY_MAX) {
+    if ((policy < DC1394_CAPTURE_POLICY_MIN)
+            || (policy > DC1394_CAPTURE_POLICY_MAX))
         return DC1394_INVALID_CAPTURE_POLICY;
-	}
-
-	if(craw->buffer==NULL || craw->capture_is_set==0) {
-		*frame_return=NULL;
-		return DC1394_CAPTURE_IS_NOT_SET;
-	}
 
     /* default: return NULL in case of failures or lack of frames */
     *frame_return = NULL;
@@ -520,30 +398,3 @@ dc1394_usb_capture_is_frame_corrupt (platform_camera_t * craw,
     return DC1394_FALSE;
 }
 
-
-#ifdef HAVE_MACOSX
-dc1394error_t
-dc1394_usb_capture_schedule_with_runloop (platform_camera_t * craw,
-        CFRunLoopRef run_loop, CFStringRef run_loop_mode)
-{
-    dc1394capture_t * capture = &(craw->capture);
-    if (craw->capture_is_set) {
-        dc1394_log_warning("schedule_with_runloop must be called before capture_setup");
-        return DC1394_FAILURE;
-    }
-
-    capture->run_loop = run_loop;
-    capture->run_loop_mode = run_loop_mode;
-    return DC1394_SUCCESS;
-}
-
-dc1394error_t
-dc1394_usb_capture_set_callback (platform_camera_t * craw,
-                             dc1394capture_callback_t callback, void * user_data)
-{
-    dc1394capture_t * capture = &(craw->capture);
-    capture->callback = callback;
-    capture->callback_user_data = user_data;
-    return DC1394_SUCCESS;
-}
-#endif
